/*
 * Copyright/Copyleft (C) 2012 Orest Tarasiuk <orest.tarasiuk@tum.de>
 *
 * This file is part of Gnome Shell Extension Blank on Lid (GSEBL).
 *
 * GSEBL is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSEBL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSEBL.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Forked from https://extensions.gnome.org/extension/237/desktop-icons-switch/
 *
 */

const Gio = imports.gi.Gio;
const Lang = imports.lang;
const ExtensionUtils = imports.misc.extensionUtils;
const Main = imports.ui.main;
const PopupMenu = imports.ui.popupMenu;
const Convenience = ExtensionUtils.getCurrentExtension().imports.convenience;

let menuItemUni, menuItemAc, menuItemBat, userMenu, iconSetting, settings;
let actionAc, actionBat;
let actionAcOrig, actionBatOrig;
let switchTextUni, switchTextAc, switchTextBat;
let showUni, showAc, showBat, resetOnLogin, inhibited;
let schemaPower = "org.gnome.settings-daemon.plugins.power";
let keyAc = "lid-close-ac-action";
let keyBat = "lid-close-battery-action";

function init()
{
    userMenu = Main.panel._statusArea.userMenu;
    settings = Convenience.getSettings();
}

function enable()
{
    iconSetting = new Gio.Settings({
        schema: schemaPower
    });
    actionAc = iconSetting.get_string(keyAc);
    actionBat = iconSetting.get_string(keyBat);

    showBat = settings.get_boolean("showbat");
    showAc = settings.get_boolean("showac");
    showUni = settings.get_boolean("showuni");
    resetOnLogin = settings.get_boolean("resetonlogin");
    inhibited = settings.get_boolean("inhibited");
    switchTextBat = settings.get_string("switchtextbat");
    switchTextAc = settings.get_string("switchtextac");
    switchTextUni = settings.get_string("switchtextuni");

    if (!inhibited){
        actionAcOrig = actionAc.toString();
        actionBatOrig = actionBat.toString();
    } else {
        actionAcOrig = settings.get_string("actionacorig");
        actionBatOrig = settings.get_string("actionbatorig");
    }

    if (resetOnLogin && inhibited){
        if (actionAc == "blank"){
            iconSetting.set_string(keyAc, actionAcOrig);
            actionAc = iconSetting.get_string(keyAc);
        }
        if (actionBat == "blank"){
            iconSetting.set_string(keyBat, actionBatOrig);
            actionBat = iconSetting.get_string(keyBat);
        }
        settings.set_boolean("inhibited", false);
    }

    if (showUni){
        menuItemUni = new PopupMenu.PopupSwitchMenuItem(
            _(switchTextUni), actionBat == "blank");
        userMenu.menu.addMenuItem(menuItemUni, 2);
        menuItemUni.connect('toggled', Lang.bind(userMenu, function(){
            actionAc = iconSetting.get_string(keyAc);
            actionBat = iconSetting.get_string(keyBat);
            if (actionBat !== "blank"){
                settings.set_boolean("inhibited", true);
                actionBatOrig = actionBat.toString();
                settings.set_string("actionbatorig", actionBatOrig);
                iconSetting.set_string(keyBat, "blank");
                actionAcOrig = actionAc.toString();
                settings.set_string("actionacorig", actionAcOrig);
                iconSetting.set_string(keyAc, "blank");
            }
            else if (actionBat == "blank"){
                iconSetting.set_string(keyAc, actionAcOrig);
                iconSetting.set_string(keyBat, actionBatOrig);
                settings.set_boolean("inhibited", false);
            }
        }));
    }
    if (showAc && !showUni){
        menuItemAc = new PopupMenu.PopupSwitchMenuItem(
            _(switchTextAc), actionAc == "blank");
        userMenu.menu.addMenuItem(menuItemAc, 2);
        menuItemAc.connect('toggled', Lang.bind(userMenu, function(){
            actionAc = iconSetting.get_string(keyAc);
            if (actionAc !== "blank"){
                settings.set_boolean("inhibited", true);
                actionAcOrig = actionAc.toString();
                settings.set_string("actionacorig", actionAcOrig);
                iconSetting.set_string(keyAc, "blank");
            }
            else if (actionAc == "blank"){
                iconSetting.set_string(keyAc, actionAcOrig);
                settings.set_boolean("inhibited", false);
            }
        }));
    }
    if (showBat && !showUni){
        menuItemBat = new PopupMenu.PopupSwitchMenuItem(
            _(switchTextBat), actionBat == "blank");
        userMenu.menu.addMenuItem(menuItemBat, 2);
        menuItemBat.connect('toggled', Lang.bind(userMenu, function(){
            actionBat = iconSetting.get_string(keyBat);
            if (actionBat !== "blank"){
                settings.set_boolean("inhibited", true);
                actionBatOrig = actionBat.toString();
                settings.set_string("actionbatorig", actionBatOrig);
                iconSetting.set_string(keyBat, "blank");
            }
            else if (actionBat == "blank"){
                iconSetting.set_string(keyBat, actionBatOrig);
                settings.set_boolean("inhibited", false);
            }
        }));

    }
}

function disable()
{
    iconSetting.set_string(keyAc, actionAcOrig);
    iconSetting.set_string(keyBat, actionBatOrig);
    settings.set_boolean("inhibited", false);
    if (menuItemUni){
        menuItemUni.destroy();
    }
    if (menuItemAc){
        menuItemAc.destroy();
    }
    if (menuItemBat){
        menuItemBat.destroy();
    }
}